@@ -53,6 +53,10 @@ from .interfaces import (
     method,             # Decorator for methods
     )
 
+from .protocol import (
+    RemoteComponent,    # Remote component implementation
+    )
+
 from .nsclient import (
     locate,             # Locate service on network
     nameserver,         # Function to locate nameserver
