@@ -26,8 +26,6 @@
 
 """Synchronous client API for PyCOM nameserver."""
 
-import zmq
-
 from . import base, constants, exceptions, interfaces, protocol
 
 
@@ -50,7 +48,7 @@ def nameserver():
         else:
             raise exceptions.ServiceNotFound("Nameserver not found")
     else:
-        _nameserver = _detect_ns(ns_conf)
+        _nameserver = protocol.detect_ns(ns_conf)
 
     return _nameserver
 
@@ -79,27 +77,3 @@ def locate(iface, service_name=None):
 # Private
 
 _nameserver = None
-
-
-def _detect_ns(host):
-    """Detect nameserver on a given host."""
-    sock = protocol.context.socket(zmq.REQ)
-    try:
-        sock.connect(host)
-    except zmq.ZMQError as err:
-        sock.close(linger=0)
-        if err.errno == zmq.EINVAL:
-            raise exceptions.ConfigurationError(
-                "Invalid nameserver address: %s" % host)
-        else:
-            raise exceptions.ServiceNotFound("Nameserver not available")
-
-    try:
-        protocol.send_request(sock, constants.IFACE_NAMESERVER,
-            constants.NS_METHOD_STAT, None,
-            timeout=constants.PROTO_DEFAULT_TIMEOUT)
-    except exceptions.ServiceNotAvailable:
-        sock.close(linger=0)
-        raise exceptions.ServiceNotFound("Nameserver not available")
-
-    return protocol.RemoteComponent(sock, constants.IFACE_NAMESERVER)
