@@ -32,9 +32,10 @@ import threading
 import zmq
 
 import pycom
-from pycom import constants, exceptions, interfaces, invoke, nsclient, protocol
-from pycom.test.utils import unittest, Replacer
-from pycom.test.test_interfaces import BaseTest as InterfacesBaseTest
+from pycom import constants, exceptions, interfaces, nsclient, protocol
+
+from .utils import unittest, Replacer
+from .test_interfaces import BaseTest as InterfacesBaseTest
 
 class BaseTest(InterfacesBaseTest):
 
@@ -66,8 +67,8 @@ class LocalNSTest(BaseTest, unittest.TestCase):
         class Nameserver(object): pass
 
         ns = pycom.nameserver()
-        self.assertIsInstance(ns, invoke.DirectInvoker)
-        self.assertIsInstance(ns.wrapped, Nameserver)
+        self.assertIsInstance(ns, pycom.BaseComponent)
+        self.assertIsInstance(ns.instance, Nameserver)
 
     def testCachedNs(self):
         @pycom.interface(constants.IFACE_NAMESERVER)
@@ -106,9 +107,9 @@ def ns_handler(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}
+        return 0, None, {}, None
     else:
-        return constants.ERROR_SERVICE_NOT_FOUND, None, None
+        return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
 
 
 class RemoteNSTest(unittest.TestCase):
@@ -167,9 +168,9 @@ def ns_handler_w_error(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}
+        return 0, None, {}, None
     else:
-        return 100500, None, None
+        return 100500, None, None, None
 
 
 class LocateFailureTest(unittest.TestCase):
@@ -211,12 +212,16 @@ def ns_handler2(request):
         constants.NS_METHOD_STAT)
 
     if request.method == constants.NS_METHOD_STAT:
-        return 0, None, {}
+        return 0, None, {}, None
     else:
         if request.args["interface"] == "iface.name":
-            return 0, None, {"address": "ipc://test_nsclient_h2"}
+            assert request.args.get("service") is None
+            return 0, None, {"address": "ipc://test_nsclient_h2"}, None
+        elif request.args["interface"] == "iface.name2":
+            assert request.args["service"] == "service.name2"
+            return 0, None, {"address": "ipc://test_nsclient_h2"}, None
         else:
-            return constants.ERROR_SERVICE_NOT_FOUND, None, None
+            return constants.ERROR_SERVICE_NOT_FOUND, None, None, None
 
 
 class LocateTest(unittest.TestCase):
@@ -247,10 +252,16 @@ class LocateTest(unittest.TestCase):
         super(LocateTest, self).tearDown()
 
     def testLocate(self):
-        invoker = pycom.locate("iface.name")
-        self.assertIsInstance(invoker, invoke.RemoteInvoker)
-        self.assertEqual(invoker.iface, "iface.name")
-        self.assertIsInstance(invoker.socket, zmq.Socket)
+        component = pycom.locate("iface.name")
+        self.assertIsInstance(component, pycom.BaseComponent)
+        self.assertEqual(component.iface, "iface.name")
+        self.assertIsInstance(component.socket, zmq.Socket)
+
+    def testLocateWService(self):
+        component = pycom.locate("iface.name2", service_name="service.name2")
+        self.assertIsInstance(component, pycom.BaseComponent)
+        self.assertEqual(component.iface, "iface.name2")
+        self.assertIsInstance(component.socket, zmq.Socket)
 
     def testLocateFail(self):
         self.assertRaises(exceptions.ServiceNotFound,
