@@ -272,13 +272,14 @@ class FakeClientSocketError(FakeClientSocket):
         }""" % constants.ERROR_METHOD_NOT_FOUND)]
 
 
-class TestSendRequestFake(unittest.TestCase):
-    # This case is using fake socket
+class RemoteComponentTest(unittest.TestCase):
+    # This case is mostly using fake socket
 
     def testSuccess(self):
         sock = FakeClientSocket()
-        result = protocol.send_request(sock, "iface.name", "method",
-            six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))[0]
+        comp = pycom.RemoteComponent(sock, "iface.name")
+        result = comp.invoke("method",
+            six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
         self.assertDictEqual(result, {
             "interface": "iface.name",
             "method": "method",
@@ -290,78 +291,67 @@ class TestSendRequestFake(unittest.TestCase):
     def testPollFailure1(self):
         sock = FakeClientSocket()
         sock.poll_success = 1
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.ServiceNotAvailable,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testPollFailure2(self):
         sock = FakeClientSocket()
         sock.poll_success = 2
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.ServiceNotAvailable,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testFailingService(self):
         sock = FakeClientSocket()
         sock.recv_success = False
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.ServiceNotAvailable,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testSendUnavailable(self):
         sock = FakeClientSocket()
         sock.send_errno = zmq.EAGAIN
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.ServiceNotAvailable,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testRecvUnavailable(self):
         sock = FakeClientSocket()
         sock.recv_errno = zmq.EAGAIN
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.ServiceNotAvailable,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testSendFailure(self):
         sock = FakeClientSocket()
         sock.send_errno = 100500
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(zmq.ZMQError,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testRecvFailure(self):
         sock = FakeClientSocket()
         sock.recv_errno = 100500
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(zmq.ZMQError,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
     def testMethodNotFound(self):
         sock = FakeClientSocketError()
+        comp = pycom.RemoteComponent(sock, "iface.name")
         self.assertRaises(exceptions.MethodNotFound,
-            protocol.send_request, sock, "iface.name", "method",
+            comp.invoke, "method",
             six.u("\u041f\u0440\u0438\u0432\u0435\u0442"))
 
 
-def fake_send_request(socket, iface, method, args, timeout=None, session_id=None):
-    assert type(socket) is object
-    assert iface == "test.iface"
-    assert method == "method"
-    assert args == "dummy_args"
-    assert timeout == 3
-    return "result", session_id
-
-
-class RemoteComponentTest(unittest.TestCase):
-
-    def testCallProtocol(self):
-        with Replacer(protocol, "send_request", fake_send_request):
-            component = protocol.RemoteComponent(object(), "test.iface")
-            self.assertIsInstance(component, pycom.BaseComponent)
-            result = component.invoke("method", args="dummy_args", timeout=3)
-            self.assertEqual(result, "result")
-
-
 # Private
 
 def _encode(s):
